]> granicus.if.org Git - neomutt/commitdiff
name unnamed enums
authorRichard Russon <rich@flatcap.org>
Thu, 13 Jul 2017 13:58:27 +0000 (14:58 +0100)
committerRichard Russon <rich@flatcap.org>
Thu, 13 Jul 2017 14:14:39 +0000 (15:14 +0100)
21 files changed:
account.h
compose.c
context.h
enter.c
handler.c
hdrline.c
imap/imap_private.h
keymap.h
mailbox.h
mime.h
mutt.h
mutt_curses.h
mutt_notmuch.c
mx.h
ncrypt/crypt_gpgme.c
nntp.h
options.h
pattern.c
pop.h
rfc822.h
smtp.c

index 22aad95d150189ec2b80ba3a1e88abcc784ba84f..7988778300c50839fc4e6586150018f4aa6f8570 100644 (file)
--- a/account.h
+++ b/account.h
@@ -23,7 +23,7 @@
 struct CissUrl;
 
 /* account types */
-enum
+enum AccountType
 {
   MUTT_ACCT_TYPE_NONE = 0,
   MUTT_ACCT_TYPE_IMAP,
index 0ff44521d0d2881738e70c5bfa30ba07e5101cf8..74f86fc37014d2ecb7ee846c0c40c6bfc007f79a 100644 (file)
--- a/compose.c
+++ b/compose.c
@@ -72,7 +72,7 @@ static const char *There_are_no_attachments = N_("There are no attachments.");
   }
 
 
-enum
+enum HeaderField
 {
   HDR_FROM = 0,
   HDR_TO,
index aa1bff6e0942a8ba85d91ddbbd155a1f003a19fa..bb49a59c58e135bbed89a84185588f9aac47e1b1 100644 (file)
--- a/context.h
+++ b/context.h
@@ -24,7 +24,7 @@
 #include <time.h>
 
 /* ACL Rights */
-enum
+enum AclRights
 {
   MUTT_ACL_LOOKUP = 0,
   MUTT_ACL_READ,
diff --git a/enter.c b/enter.c
index 03887686a6a51c4edd41fbda3ff64909c1a97b84..a9a27876a0cf7d1a23d0f38cf9db51bee7709d4c 100644 (file)
--- a/enter.c
+++ b/enter.c
@@ -35,7 +35,7 @@
 #include "protos.h"
 
 /* redraw flags for mutt_enter_string() */
-enum
+enum RedrawFlags
 {
   MUTT_REDRAW_INIT = 1, /* go to end of line and redraw */
   MUTT_REDRAW_LINE      /* redraw entire line */
index 21bbc791c05684ca1285ff35cbbc01da43535df8..11b8b09238e5cc801860a5f8c9142d4de34ffabb 100644 (file)
--- a/handler.c
+++ b/handler.c
@@ -470,7 +470,7 @@ static void decode_uuencoded(struct State *s, long len, int istext, iconv_t cd)
 
 #define IndentSize (4)
 
-enum
+enum RichAttribs
 {
   RICH_PARAM = 0,
   RICH_BOLD,
index 8cf2a4d913234e6c53b04442e8e3de472cac6f45..fd87c65f2417a7025b778f0306bf68b3f364eb62 100644 (file)
--- a/hdrline.c
+++ b/hdrline.c
@@ -49,7 +49,7 @@
 #include "mutt_notmuch.h"
 #endif
 
-enum
+enum FlagChars
 {
   /* Indexing into the Flagchars variable ($flag_chars) */
   FlagCharTagged,
index 4189e01333c3b52dd5ecf3b26ea08a5e486ee614..b40b2f45de1062d26fac055afd133ca4070e64bc 100644 (file)
@@ -81,7 +81,7 @@ struct Progress;
 /* length of "DD-MMM-YYYY HH:MM:SS +ZZzz" (null-terminated) */
 #define IMAP_DATELEN 27
 
-enum
+enum ImapFlags
 {
   IMAP_FATAL = 1,
   IMAP_BYE
index 81cf5f722e510e42f41000e405d8bc57e4310043..abefd6d91171f4b2a2f391b3e369b3a81af7ec0e 100644 (file)
--- a/keymap.h
+++ b/keymap.h
@@ -50,7 +50,7 @@ void km_init(void);
 void km_error_key(int menu);
 void mutt_what_key(void);
 
-enum
+enum MenuTypes
 {
   MENU_ALIAS,
   MENU_ATTACH,
index 910cfee2443e1c032635d48d1cc911cb8b838d6f..f8810c6205ba93393985db19f0e6724809bd4d5c 100644 (file)
--- a/mailbox.h
+++ b/mailbox.h
@@ -42,7 +42,7 @@ struct Context;
 #define MUTT_SET_DRAFT (1 << 1) /* set the message draft flag */
 
 /* return values from mx_check_mailbox() */
-enum
+enum MxCheckReturns
 {
   MUTT_NEW_MAIL = 1, /* new mail received in mailbox */
   MUTT_LOCKED,       /* couldn't lock the mailbox */
diff --git a/mime.h b/mime.h
index 1be76b55fb5f46fae72efbebcddd7ad4da264054..785abf92d67ff74bf2b489cb8708830957d6a03d 100644 (file)
--- a/mime.h
+++ b/mime.h
@@ -19,7 +19,7 @@
 #define _MUTT_MIME_H 1
 
 /* Content-Type */
-enum
+enum ContentType
 {
   TYPEOTHER,
   TYPEAUDIO,
diff --git a/mx.h b/mx.h
index d6ddf3aedca003dc2ffdaa7d5a6e4eb70c50197f..8990f1b767f99f00c2217ddd7f0554215b87c340 100644 (file)
--- a/mx.h
+++ b/mx.h
@@ -60,7 +60,7 @@ struct MxOps
 };
 
 /* supported mailbox formats */
-enum
+enum MailboxFormat
 {
   MUTT_MBOX = 1,
   MUTT_MMDF,
index a6a5e8f63ad51d4a6e81cc47069709db640fe9a3..c73bac04530f954b4bf11e849b58be2fca47f052 100644 (file)
@@ -3319,7 +3319,7 @@ static unsigned int key_check_cap(gpgme_key_t key, enum KeyCap cap)
   return ret;
 }
 
-enum
+enum KeyInfo
 {
   KIP_NAME = 0,
   KIP_AKA,
diff --git a/nntp.h b/nntp.h
index 9627ea2cf4ede0c59bf0da7e5294351f54e734f6..4b15ef7d9e2a0605b285292838f71ff095efb69e 100644 (file)
--- a/nntp.h
+++ b/nntp.h
@@ -46,7 +46,7 @@ struct Context;
 #define anum_t uint32_t
 #define ANUM "%u"
 
-enum
+enum NntpStatus
 {
   NNTP_NONE = 0,
   NNTP_OK,
index 2874306eda24ab84727309c00270256165e2a8c2..0de0c6a13e9cd8699500a552acebe6612e17a290 100644 (file)
--- a/options.h
+++ b/options.h
@@ -19,7 +19,7 @@
 #define _MUTT_OPTIONS_H_ 1
 
 /* boolean vars */
-enum
+enum GlobalBool
 {
   OPTALLOW8BIT,
   OPTALLOWANSI,
index 6fc8a7490088ac015016d5c3466ac04b679f14b3..3d4f0b4056a2cf8d4ef5304947b012b0fec5a404 100644 (file)
--- a/pattern.c
+++ b/pattern.c
@@ -64,7 +64,7 @@
 #endif
 
 /* Error codes for eat_range_by_regexp */
-enum
+enum EatRangeError
 {
   RANGE_E_OK,
   RANGE_E_SYNTAX,
diff --git a/pop.h b/pop.h
index 5d138406ed15b4501c0764a4265745efcef2201d..3a4d50c396b1d3303f137b187d84ab0114bb0bde 100644 (file)
--- a/pop.h
+++ b/pop.h
@@ -35,7 +35,7 @@ struct Progress;
 /* maximal length of the server response (RFC1939) */
 #define POP_CMD_RESPONSE 512
 
-enum
+enum PopStatus
 {
   /* Status */
   POP_NONE = 0,
index b648b836c25ec01864ce71bb398a0ee306318d7c..60074b1a5208f6c3283ed40f996f96da3a55c7c2 100644 (file)
--- a/rfc822.h
+++ b/rfc822.h
@@ -25,7 +25,7 @@
 #include "lib.h"
 
 /* possible values for RFC822Error */
-enum
+enum AddressError
 {
   ERR_MEMORY = 1,
   ERR_MISMATCH_PAREN,
diff --git a/smtp.c b/smtp.c
index cee0257ca121de5dc91abf773581d482c43f3fb8..bb7198776a896414324ede433232b03533fc24fc 100644 (file)
--- a/smtp.c
+++ b/smtp.c
@@ -63,7 +63,7 @@
 #define SMTP_AUTH_UNAVAIL 1
 #define SMTP_AUTH_FAIL -1
 
-enum
+enum SmtpCapability
 {
   STARTTLS,
   AUTH,
diff --git a/mutt.h b/mutt.h
index 04840ae7caca94855422069d02783de0af4f04d7..a4861b07dc86570087a0050a15d6edd62f185751 100644 (file)
--- a/mutt.h
+++ b/mutt.h
@@ -123,7 +123,7 @@ struct State;
 #define MUTT_THREAD_NEXT_UNREAD (1 << 4)
 #define MUTT_THREAD_FLAGGED     (1 << 5)
 
-enum
+enum MuttMisc
 {
   /* modes for mutt_view_attachment() */
   MUTT_REGULAR = 1,
index 57ff291ae3e43e5c4f974aa926a7590d9b9e282c..cf35b1bfd793e092abc1aa71210dfbeef63877b5 100644 (file)
@@ -121,7 +121,7 @@ void mutt_need_hard_redraw(void);
  * Support for color
  */
 
-enum
+enum ColorId
 {
   MT_COLOR_HDEFAULT = 0,
   MT_COLOR_QUOTED,
index 5a0eda1dd973cd65d7667243ddf013ce1ad268a6..60dba5d60afdb9bfe9620c712b1cc8a0fa284448 100644 (file)
     LIBNOTMUCH_MICRO_VERSION >= (_micro)))
 
 /**
* enum anonymous - Query Types
  *
  * Read whole-thread or matching messages only?
  */
-enum
+enum NmQueryType
 {
   NM_QUERY_TYPE_MESGS = 1, /**< Default: Messages only */
   NM_QUERY_TYPE_THREADS    /**< Whole threads */
@@ -121,7 +121,7 @@ void mutt_need_hard_redraw(void);
 
 /**
- * enum anonymous - Query Types
+ * enum NmQueryType - Query Types
  *
  * Read whole-thread or matching messages only?